# -*- coding: utf-8 -*-

PAGSEGURO_ACCOUNT_EMAIL = 'contato@pizze.me'
PAGSEGURO_TOKEN = 'F36ADE4A0F3D4AB8A96E968D486CA0D4'
